get_basic_spells

Function get_basic_spells 

pub fn get_basic_spells(ctx: &EffectContext<'_>, card_id: CardId) -> Vec<String>
Get the list of basic spell abilities from a card that can be cast via a play effect.

Mirrors Java’s AbilityUtils.getBasicSpellsFromPlayEffect(). Returns the ability texts that can be cast (non-land spells).