Module charm_effect

Module charm_effect 

Structs

CharmEffect

Enums

ChoiceRestriction
Scope of a ChoiceRestriction$ on SP$ Charm. Past selections within this scope are filtered out of the available mode list. Mirrors Java’s CharmEffect string literals.

Functions

chain_abilities
Chain a list of sub-abilities (modes) onto a root spell ability. Mirrors Java’s CharmEffect.chainAbilities(SpellAbility, List<AbilitySub>).
make_choices
Make charm mode choices during pre-cast. Mirrors Java’s CharmEffect.makeChoices(SpellAbility).
make_choices_precast
make_choices_precast_with_count
make_formated_description
Build a formatted description string for charm mode choices. Mirrors Java’s CharmEffect.makeFormatedDescription(SpellAbility).
make_possible_options
Collect valid mode indices for a charm/modal spell. Mirrors Java’s CharmEffect.makePossibleOptions(SpellAbility).