pub fn build_spell_ability(sa: &mut SpellAbility)Expand description
Configure the spell ability during construction.
Mirrors Java ControlSpellEffect.buildSpellAbility — sets the target zone
to Stack so the ability targets spells on the stack.
pub fn build_spell_ability(sa: &mut SpellAbility)Configure the spell ability during construction.
Mirrors Java ControlSpellEffect.buildSpellAbility — sets the target zone
to Stack so the ability targets spells on the stack.