Structs
Functions
- build_
spell_ ability - Configure the spell ability during construction.
Mirrors Java
CopySpellAbilityEffect.buildSpellAbility— sets the target zone to Stack so the ability targets spells on the stack.
CopySpellAbilityEffect.buildSpellAbility — sets the target zone
to Stack so the ability targets spells on the stack.