CountersMove effect — move counters between permanents.
Ported from Java’s CountersMoveEffect.java.
Move N counters of a type from one permanent to another.
CountersMove effect — move counters between permanents.
Ported from Java’s CountersMoveEffect.java.
Move N counters of a type from one permanent to another.