CountersMultiply effect — double (or multiply) counters on a permanent.
Ported from Java’s CountersMultiplyEffect.java.
Double the number of each type of counter on target permanent.
CountersMultiply effect — double (or multiply) counters on a permanent.
Ported from Java’s CountersMultiplyEffect.java.
Double the number of each type of counter on target permanent.