DamagePrevent effect — prevent the next N damage to a target.
Ported from Java’s DamagePreventEffect.java.
Prevent the next N damage that would be dealt to target creature/player.
Structs
Functions
- run
- End-of-turn revert for damage prevention. Mirrors the
GameCommand.run()in JavaDamagePreventEffectthat resets damage prevention shields when the effect expires.