Endure — creature endures: either put +1/+1 counters on it, or create a Spirit token with power/toughness equal to the endure amount. Ported from Java’s EndureEffect.
Endure — creature endures: either put +1/+1 counters on it, or create a Spirit token with power/toughness equal to the endure amount. Ported from Java’s EndureEffect.