Module learn_effect

Module learn_effect 

Learn effect — reveal a Lesson from outside the game, or discard to draw.

Ported from Java’s LearnEffect.java + Player.learnLesson(). Learn: You may reveal a Lesson card you own from outside the game and put it into your hand, or discard a card to draw a card.

Structs

LearnEffect