Module meld_effect

Module meld_effect 

Meld effect — exile two named cards, return melded as one creature.

Ported 1:1 from Java’s MeldEffect.java. Meld: Exile two specific named permanents you control and own, then return the primary card to the battlefield transformed (melded) with the secondary card linked to it.

Structs

MeldEffect