pub fn create_skip_phase_effect(
game: &mut GameState,
player: PlayerId,
phase: &str,
)Expand description
Create a skip-phase effect for use by static or replacement abilities.
Mirrors Java’s SkipPhaseEffect.createSkipPhaseEffect(...).
Creates an effect that will cause the specified player to skip the specified phase on their next turn. Used by cards like Stasis, Teferi’s Protection, etc.