Module types

Module types 

Structs

ActivatableAction
ManaAbilityOption
PlayOption
PriorityActionSpace

Enums

BinaryChoiceKind
Java-parity binary choice kinds (PlayerController.BinaryChoiceType).
CombatCostAction
The action a player takes when asked to pay an attack cost (Propaganda, Ghostly Prison).
GameEntity
A game entity that can be a player or a card (permanent). Used by effects like Proliferate that operate on mixed entity lists. Mirrors Java’s GameEntity hierarchy used in chooseEntitiesForEffect.
MainPhaseAction
The action a player takes during a main phase.
ManaCostAction
The action a player takes when interactively paying a mana cost for a spell.
PlayCardMode
RollSwapChoice
TargetChoice
A target choice that can be a player, a card, or nothing.