pub enum CombatCostAction {
TapLand {
card_id: CardId,
mana_ability_index: Option<usize>,
express_choice: Option<u16>,
},
UntapLand(CardId),
Pay,
Decline,
}Expand description
The action a player takes when asked to pay an attack cost (Propaganda, Ghostly Prison).
Variants
TapLand
Tap an untapped land to add mana to the pool.
UntapLand(CardId)
Untap a tapped land and remove its mana from the pool (undo).
Pay
Pay the cost from the mana pool.
Decline
Decline to pay — remove this attacker.