pub enum MainPhaseAction {
Pass,
Play(PlayOption),
ActivateMana(CardId, Option<usize>, Option<u16>),
UntapMana(CardId),
ActivateAbility(CardId, usize),
}Expand description
The action a player takes during a main phase.
Variants
Pass
Pass priority / end main phase.
Play(PlayOption)
Play a card from hand / graveyard / exile / command with a specific cast mode.
ActivateMana(CardId, Option<usize>, Option<u16>)
Tap an untapped land on the battlefield to add its mana to the pool. Optional ability index selects a specific mana ability (dual lands).
UntapMana(CardId)
Untap a tapped land and remove its mana from the pool (undo tap).
ActivateAbility(CardId, usize)
Activate an ability on a permanent. (source card, ability index)