pub enum PlayCardMode {
Normal,
BackFaceLand,
RoomRightSplit,
Alternative(AlternativeCost),
StaticAlternative,
ForetellExile,
UnlockDoor,
}Variants
Normal
BackFaceLand
RoomRightSplit
Cast the right split face of a Room card from hand.
Alternative(AlternativeCost)
StaticAlternative
Alternative cost granted by Mode$ AlternativeCost static abilities.
ForetellExile
UnlockDoor
Unlock a Room door on a permanent already on the battlefield.
Mirrors Java’s StaticAbilityApiBased for ST$ UnlockDoor which falls
through to the CastSpell branch in the harness (not ActivateAbility).