pub struct AttackRestriction {
pub attacker: CardId,
pub types: HashSet<AttackRestrictionType>,
pub cant_attack: bool,
pub cant_attack_defenders: Vec<DefenderId>,
}Expand description
Per-creature attack restriction state.
Mirrors Java’s AttackRestriction.java.
Fields
attacker: CardIdtypes: HashSet<AttackRestrictionType>cant_attack: boolcant_attack_defenders: Vec<DefenderId>Implementations
Sourceimpl AttackRestriction
impl AttackRestriction
pub fn new( attacker: CardId, cards: &[Card], possible_defenders: &[DefenderId], game: &GameState, ) -> Self
Sourcepub fn can_attack(&self, defender: DefenderId) -> bool
pub fn can_attack(&self, defender: DefenderId) -> bool
Can this creature attack the given defender?
Sourcepub fn can_attack_with(
&self,
defender: DefenderId,
attackers: &[(CardId, DefenderId)],
cards: &[Card],
) -> bool
pub fn can_attack_with( &self, defender: DefenderId, attackers: &[(CardId, DefenderId)], cards: &[Card], ) -> bool
Can this creature attack the given defender with the given set of attackers? Checks both per-defender and per-attacker-set violations.
Sourcepub fn get_violations(
&self,
attackers: &[(CardId, DefenderId)],
cards: &[Card],
) -> HashSet<AttackRestrictionType>
pub fn get_violations( &self, attackers: &[(CardId, DefenderId)], cards: &[Card], ) -> HashSet<AttackRestrictionType>
Get restriction type violations for the given set of attackers.
pub fn get_types(&self) -> &HashSet<AttackRestrictionType>