Module attack_cost

Module attack_cost 

Attack cost computation (Propaganda, Ghostly Prison, etc.).

Mirrors Java Forge’s CombatUtil.getAttackCost() — scans battlefield for CantAttackUnless static abilities and accumulates the mana cost an attacker must pay to attack a given defender.

Functions

get_attack_cost
Compute the total generic mana cost required for attacker to attack defender.