pub struct TriggerReplacementBase {
pub card_trait_base: CardTraitBase,
pub valid_host_zones: Option<Vec<ZoneType>>,
pub overriding_ability: Option<SpellAbility>,
}Expand description
Port of Java TriggerReplacementBase.
Java:
public abstract class TriggerReplacementBase extends CardTraitBase implements IIdentifiable, Cloneable
Fields
card_trait_base: CardTraitBasevalid_host_zones: Option<Vec<ZoneType>>overriding_ability: Option<SpellAbility>Implementations
Sourceimpl TriggerReplacementBase
impl TriggerReplacementBase
pub fn set_host_card_id(&mut self, id: CardId)
pub fn set_keyword(&mut self, kw: KeywordInterface)
pub fn set_card_state(&mut self, state: CardState)
pub fn get_active_zone(&self) -> Option<&[ZoneType]>
pub fn set_active_zone(&mut self, zones: Vec<ZoneType>)
pub fn zones_check( &self, game: &GameState, host_card_zone: Option<ZoneType>, ) -> bool
pub fn get_overriding_ability(&self) -> Option<&SpellAbility>
pub fn set_overriding_ability(&mut self, overriding_ability: SpellAbility)
Sourcepub fn ensure_ability(&mut self) -> Option<&mut SpellAbility>
pub fn ensure_ability(&mut self) -> Option<&mut SpellAbility>
Port of Java ensureAbility().
The Java base type is abstract and concrete trigger/replacement classes
may lazily populate the overriding ability. In the current Rust port,
the base owns the resolved ability directly, so ensure_ability
returns the stored ability when present.
pub fn change_text(&mut self)
pub fn change_text_intrinsic( &mut self, color_map: HashMap<String, String>, type_map: HashMap<String, String>, )