Compleated

Struct Compleated 

pub struct Compleated {
    pub base: KeywordInstanceData,
}
Compleated keyword data. This planeswalker enters with two fewer loyalty counters for each Phyrexian mana symbol paid with life.

Fields

base: KeywordInstanceData

Implementations

Source

impl Compleated

pub fn new(original: String) -> Self

Create a new Compleated keyword.

pub fn parse(&mut self, _details: &str)

Parse the details string (no-op, simple keyword variant).

pub fn get_title(&self) -> String

Get the display title.

pub fn format_reminder_text(&self, reminder_text: &str) -> String

Format reminder text. In Java this reads Phyrexian mana shards from the host card’s mana cost. Simplified here to return the base reminder text.