Keyword

Enum Keyword 

pub enum Keyword {
Show 200 variants Undefined, Absorb, Adapt, Affinity, Afflict, Afterlife, Aftermath, Amplify, Annihilator, Ascend, Assist, AuraSwap, Awaken, Backup, Banding, BandsWith, Bargain, BattleCry, Bestow, Blitz, Bloodthirst, Bushido, Buyback, Cascade, Casualty, Champion, Changeling, ChooseABackground, Cipher, Companion, Compleated, Conspire, Convoke, Craft, Crew, CumulativeUpkeep, Cycling, Dash, Daybound, Deathtouch, Decayed, Defender, Delve, Demonstrate, Dethrone, Devour, Devoid, Disguise, Disturb, DoctorsCompanion, DoubleAgenda, DoubleStrike, DoubleTeam, Dredge, Echo, Embalm, Emerge, Enchant, Encore, Enlist, Entwine, Epic, Equip, Escape, Escalate, Eternalize, Evoke, Evolve, Exalted, Exploit, Extort, Fabricate, Fading, Fear, Firebending, FirstStrike, Flanking, Flash, Flashback, Flying, ForMirrodin, Foretell, Fortify, Freerunning, Frenzy, Fuse, Gift, Graft, Gravestorm, Harmonize, Haste, Haunt, Hexproof, Hideaway, HiddenAgenda, Horsemanship, Impending, Improvise, Indestructible, Infect, Ingest, Intimidate, Kicker, JobSelect, JumpStart, Landwalk, LevelUp, Lifelink, LivingMetal, LivingWeapon, Madness, Mayhem, Melee, Mentor, Menace, Megamorph, Miracle, Mobilize, Monstrosity, Modular, MoreThanMeetsTheEye, Morph, Multikicker, Mutate, Myriad, Nightbound, Ninjutsu, Outlast, Offering, Offspring, Overload, Partner, PartnerWith, Persist, Phasing, Plot, Poisonous, Protection, Prototype, Provoke, Prowess, Prowl, Rampage, Ravenous, Reach, ReadAhead, Rebound, Recover, Reconfigure, Reflect, Reinforce, Renown, Replicate, Retrace, Riot, Ripple, Saddle, Scavenge, Shadow, Shroud, Skulk, Sneak, Soulbond, Soulshift, SpaceSculptor, Specialize, Spectacle, Splice, SplitSecond, Spree, Squad, StartYourEngines, StartingIntensity, Station, Storm, Strive, Sunburst, Surge, Suspend, Tiered, Toxic, Training, Trample, Transfigure, Transmute, Tribute, TypeCycling, UmbraArmor, Undaunted, Undying, Unearth, Unleash, Vanishing, Vigilance, Ward, Warp, WebSlinging, Wither, MayFlashCost, MayFlashSac,
}
The Keyword enum with all keyword variants. Mirrors Java’s Keyword enum with 213 entries.

Variants



Undefined



Absorb



Adapt



Affinity



Afflict



Afterlife



Aftermath



Amplify



Annihilator



Ascend



Assist



AuraSwap



Awaken



Backup



Banding



BandsWith



Bargain



BattleCry



Bestow



Blitz



Bloodthirst



Bushido



Buyback



Cascade



Casualty



Champion



Changeling



ChooseABackground



Cipher



Companion



Compleated



Conspire



Convoke



Craft



Crew



CumulativeUpkeep



Cycling



Dash



Daybound



Deathtouch



Decayed



Defender



Delve



Demonstrate



Dethrone



Devour



Devoid



Disguise



Disturb



DoctorsCompanion



DoubleAgenda



DoubleStrike



DoubleTeam



Dredge



Echo



Embalm



Emerge



Enchant



Encore



Enlist



Entwine



Epic



Equip



Escape



Escalate



Eternalize



Evoke



Evolve



Exalted



Exploit



Extort



Fabricate



Fading



Fear



Firebending



FirstStrike



Flanking



Flash



Flashback



Flying



ForMirrodin



Foretell



Fortify



Freerunning



Frenzy



Fuse



Gift



Graft



Gravestorm



Harmonize



Haste



Haunt



Hexproof



Hideaway



HiddenAgenda



Horsemanship



Impending



Improvise



Indestructible



Infect



Ingest



Intimidate



Kicker



JobSelect



JumpStart



Landwalk



LevelUp



LivingMetal



LivingWeapon



Madness



Mayhem



Melee



Mentor



Menace



Megamorph



Miracle



Mobilize



Monstrosity



Modular



MoreThanMeetsTheEye



Morph



Multikicker



Mutate



Myriad



Nightbound



Ninjutsu



Outlast



Offering



Offspring



Overload



Partner



PartnerWith



Persist



Phasing



Plot



Poisonous



Protection



Prototype



Provoke



Prowess



Prowl



Rampage



Ravenous



Reach



ReadAhead



Rebound



Recover



Reconfigure



Reflect



Reinforce



Renown



Replicate



Retrace



Riot



Ripple



Saddle



Scavenge



Shadow



Shroud



Skulk



Sneak



Soulbond



Soulshift



SpaceSculptor



Specialize



Spectacle



Splice



SplitSecond



Spree



Squad



StartYourEngines



StartingIntensity



Station



Storm



Strive



Sunburst



Surge



Suspend



Tiered



Toxic



Training



Trample



Transfigure



Transmute



Tribute



TypeCycling



UmbraArmor



Undaunted



Undying



Unearth



Unleash



Vanishing



Vigilance



Ward



Warp



WebSlinging



Wither



MayFlashCost



MayFlashSac

Implementations

Source

impl Keyword

pub fn display_name(&self) -> &'static str

Get the display name for this keyword.

pub fn is_multiple_redundant(&self) -> bool

Whether multiple instances of this keyword are redundant.

pub fn smart_value_of(value: &str) -> Keyword

Look up a keyword by its display name (case-insensitive).

pub fn all_keywords() -> impl Iterator<Item = Keyword>

Return an iterator over all keyword variants (excluding Undefined).