pub struct Mayhem {
pub inner: KeywordWithCost,
pub no_cost: bool,
}Expand description
Mayhem keyword data. You may cast this card from your graveyard for its cost if you discarded it this turn.
Fields
inner: KeywordWithCostno_cost: boolWhether there is no cost (play for free from graveyard).
Implementations