pub struct Suspend {
pub inner: KeywordWithCostAndAmount,
pub without_cost_and_amount: bool,
}Expand description
Suspend keyword data. Pay cost and exile with time counters. Remove one each upkeep. When the last is removed, cast without paying mana cost.
Fields
inner: KeywordWithCostAndAmountwithout_cost_and_amount: boolWhether this suspend has no cost and no amount (intrinsic suspend).
Implementations