do_phasing

Function do_phasing 

pub fn do_phasing(game: &mut GameState, turn_player: PlayerId)
Performs the phasing step at the beginning of the untap step. Mirrors Java’s Untap.doPhasing().

Phase in all directly-phased-out permanents controlled by the active player. Phase out all permanents with phasing controlled by the active player.