mode_check

Function mode_check 

pub fn mode_check(effect: &ReplacementEffect, event: &ReplacementType) -> bool
Check if this effect’s event type matches the given event for AddCounter purposes.

Returns true if event is AddCounter, or if event is Moved and the effect handles counter-on-move (has a CounterMap interaction).

Mirrors Java ReplaceAddCounter.modeCheck().