pub enum ReplacementLayer {
CantHappen = 0,
Control = 1,
Copy = 2,
Transform = 3,
Other = 4,
}Expand description
CR 614 / CR 616 layer ordering for replacement effects.
Multiple replacement effects that apply to the same event are applied in the order below. Within the same layer the affected player chooses the order.
Reference: CR 616.1, Java ReplacementLayer.java.
Variants
CantHappen = 0
CR 614.17 — effects that say an event “can’t happen” (highest priority).
Control = 1
CR 616.1b — control-changing replacement effects.
Copy = 2
CR 616.1c — copy replacement effects.
Transform = 3
CR 616.1d — transform replacement effects.
Other = 4
All other replacement effects (damage prevention, zone rerouting, etc.).
Implementations
Sourceimpl ReplacementLayer
impl ReplacementLayer
Sourcepub fn smart_value_of(value: &str) -> Option<Self>
pub fn smart_value_of(value: &str) -> Option<Self>
Case-insensitive Layer$ value parser. Mirrors Java
ReplacementLayer.smartValueOf(). Returns None if unrecognised.