has_split_second_on_stack

Function has_split_second_on_stack 

pub fn has_split_second_on_stack(game: &GameState) -> bool
Check whether any spell on the stack has split second. Split second prevents players from casting spells or activating abilities (except mana abilities) while it’s on the stack. Single source of truth — used by spell, ability, and ability_activated modules.