pub struct SpellAbilityCondition {
pub variables: SpellAbilityVariables,
}Expand description
Condition checks for a spell ability.
Mirrors Java’s SpellAbilityCondition — wraps SpellAbilityVariables
and evaluates whether conditions are satisfied at resolution time.
Fields
variables: SpellAbilityVariablesImplementations
Sourceimpl SpellAbilityCondition
impl SpellAbilityCondition
Sourcepub fn set_conditions(&mut self, params: &Params)
pub fn set_conditions(&mut self, params: &Params)
Parse conditions from ability params.
Mirrors Java’s SpellAbilityCondition.setConditions(SpellAbility).
pub fn set_conditions_parsed(&mut self, params: &ParsedParams<'_>)
Sourcepub fn are_met(&self, game: &GameState, sa: &SpellAbility) -> bool
pub fn are_met(&self, game: &GameState, sa: &SpellAbility) -> bool
Check if all conditions are met for the given spell ability.
Mirrors Java’s SpellAbilityCondition.areMet(SpellAbility).