pub fn is_api(api: ApiType) -> impl Fn(&SpellAbility) -> boolExpand description
Returns a predicate that matches spell abilities with the given API type.
Mirrors Java’s SpellAbilityPredicates.isApi(ApiType).
pub fn is_api(api: ApiType) -> impl Fn(&SpellAbility) -> boolReturns a predicate that matches spell abilities with the given API type.
Mirrors Java’s SpellAbilityPredicates.isApi(ApiType).