pub enum TargetKind {
Player,
Any,
Creature(Option<String>),
Permanent(Option<String>),
CardInZone {
zone: ZoneType,
filter: Option<String>,
},
Spell,
None,
}Expand description
What kinds of targets a spell can select.
Mirrors Java’s TargetRestrictions.getValidTgts() parsed target types.
Variants
Player
Player only (e.g. “ValidTgts$ Player”)
Any
Any player or creature (e.g. “ValidTgts$ Any”)
Creature(Option<String>)
Creature with optional filter (e.g. “ValidTgts$ Creature.nonBlack”)
Permanent(Option<String>)
Any permanent on the battlefield with optional filter (e.g. “ValidTgts$ Permanent.nonLand+OppCtrl”)
CardInZone
Card in a specific zone with optional filter (e.g. Raise Dead from graveyard)
Spell
Spell on the stack (for Counter effects, e.g. “ValidTgts$ Spell”)
None
No targets