Layer

pub enum Layer {
    Control = 2,
    Text = 3,
    Type = 4,
    Color = 5,
    Ability = 6,
    Characteristic = 70,
    SetPT = 71,
    ModifyPT = 72,
    Rules = 80,
}
CR 613 layer ordering for continuous effects.

Effects are applied in ascending numeric order. Timestamp ordering within the same layer is preserved by the order in which effects are collected (battlefield entry order in GameState.cards).

Reference: https://magic.wizards.com/en/rules CR 613

Variants



Control = 2

Layer 2 — control-changing effects.



Text = 3

Layer 3 — text-changing effects.



Type = 4

Layer 4 — type-changing effects.



Color = 5

Layer 5 — color-changing effects.



Ability = 6

Layer 6 — ability-adding / removing.



Characteristic = 70

Layer 7a — characteristic-defining P/T (CDAs).



SetPT = 71

Layer 7b — P/T set to an absolute value.



ModifyPT = 72

Layer 7c — P/T modifications: bonuses and penalties.



Rules = 80

Layer 7d / rules-modifying — MayPlay, AdjustLandPlays, Goad, etc.