StaticAbilityIr

Struct StaticAbilityIr 

pub struct StaticAbilityIr {
Show 152 fields pub card_trait_requirements: CardTraitRequirementsIr, pub valid_card: Option<CompiledSelector>, pub valid_card_text: Option<String>, pub valid_cards_text: Option<String>, pub valid_player: Option<CompiledSelector>, pub affected: Option<CompiledSelector>, pub affected_text: Option<String>, pub affected_zone: Option<ZoneType>, pub affected_zone_text: Option<String>, pub affected_zones: Vec<ZoneType>, pub valid_zone: Vec<ZoneType>, pub may_play: bool, pub may_play_alt_mana_cost: Option<String>, pub counter_type_text: Option<String>, pub counter_type: Option<CounterType>, pub caster: Option<CompiledSelector>, pub activator: Option<CompiledSelector>, pub player: Option<CompiledSelector>, pub valid_sa: Option<String>, pub valid_mode: Option<String>, pub valid_trigger: Option<String>, pub valid_cause: Option<CompiledSelector>, pub valid_cause_text: Option<String>, pub valid_source: Option<CompiledSelector>, pub valid_activator: Option<CompiledSelector>, pub for_cost: Option<bool>, pub is_combat: Option<bool>, pub origin_zones: Vec<ZoneType>, pub destination_zones: Vec<ZoneType>, pub combat_damage: Option<bool>, pub sorcery_speed: bool, pub only_sorcery_speed: bool, pub cmc_gt: Option<String>, pub num_limit_each_turn: Option<i32>, pub activator_raw: Option<String>, pub cost: Option<String>, pub gain_control_text: Option<String>, pub add_power_text: Option<String>, pub add_toughness_text: Option<String>, pub add_type_text: Option<String>, pub set_power_text: Option<String>, pub set_toughness_text: Option<String>, pub add_keyword_text: Option<String>, pub remove_all_abilities: bool, pub add_ability_text: Option<String>, pub add_trigger_text: Option<String>, pub add_static_ability_text: Option<String>, pub adjust_land_plays_text: Option<String>, pub type_filter: Option<String>, pub mana_conversion: Option<String>, pub except_cause_text: Option<String>, pub restriction_text: Option<String>, pub x_alternative_text: Option<String>, pub announce_text: Option<String>, pub mana_restriction_text: Option<String>, pub stack_description_text: Option<String>, pub cost_desc_text: Option<String>, pub description_text: Option<String>, pub draw_limit: Option<i32>, pub set_max_hand_size: Option<String>, pub raise_max_hand_size: Option<String>, pub named_text: Option<String>, pub trigger_text: Option<String>, pub valid_defender: Option<CompiledSelector>, pub valid_defender_text: Option<String>, pub max_attackers: Option<String>, pub max_blockers: Option<String>, pub valid_attacked: Option<CompiledSelector>, pub valid_creature: Option<CompiledSelector>, pub valid_entity: Option<CompiledSelector>, pub is_present: Option<CompiledSelector>, pub valid_attacker: Option<CompiledSelector>, pub valid_blocker: Option<CompiledSelector>, pub valid_blocker_text: Option<String>, pub valid_attacker_relative: Option<CompiledSelector>, pub has_valid_attacker_relative: bool, pub valid_blocker_relative: Option<CompiledSelector>, pub has_valid_blocker_relative: bool, pub unless_defender_text: Option<String>, pub kw_text: Option<String>, pub valid_keyword_text: Option<String>, pub value_text: Option<String>, pub mana_type_text: Option<String>, pub result_text: Option<String>, pub new_time_text: Option<String>, pub present_compare_text: Option<String>, pub check_svar_text: Option<String>, pub svar_compare_text: Option<String>, pub min_text: Option<String>, pub max_text: Option<String>, pub additional_text: Option<String>, pub attacker_text: Option<String>, pub target_text: Option<String>, pub trigger: bool, pub twice: bool, pub only_source_abs: bool, pub optional: bool, pub num_value: Option<i32>, pub defender_not_nearest_to_you_in_chosen_direction: bool, pub effect_zone_all: bool, pub effect_zones: Vec<ZoneType>, pub valid_target: Option<CompiledSelector>, pub valid_target_text: Option<String>, pub valid_spell: Option<String>, pub for_each_shard: Option<String>, pub amount: Option<String>, pub min_mana: Option<i32>, pub raise_to: bool, pub may_play_ignore_type: bool, pub may_play_ignore_color: bool, pub may_play_snow_ignore_color: bool, pub color: Option<String>, pub ignore_generic: bool, pub only_first_spell: bool, pub unless_valid_target: bool, pub relative: bool, pub target: Option<CompiledSelector>, pub valid_card_to_target: Option<CompiledSelector>, pub exception_sba: bool, pub exceptions: Option<CompiledSelector>, pub has_valid_card: bool, pub has_valid_player: bool, pub max_num: Option<i32>, pub active_zones: Vec<ZoneType>, pub phases_text: Option<String>, pub condition_text: Option<String>, pub player_turn_text: Option<String>, pub top_card_of_library_is: Option<String>, pub class_level_min: Option<i32>, pub check_third_svar: Option<String>, pub third_svar_compare: Option<String>, pub check_fourth_svar: Option<String>, pub fourth_svar_compare: Option<String>, pub add_power: bool, pub add_toughness: bool, pub set_power: bool, pub set_toughness: bool, pub add_keyword: bool, pub gain_control_param: bool, pub add_type: bool, pub remove_type: bool, pub add_color: bool, pub remove_color: bool, pub set_color: bool, pub characteristic_defining: bool, pub has_text_layer_key: bool, pub has_type_layer_key: bool, pub has_color_layer_key: bool, pub has_ability_layer_key: bool, pub has_rules_layer_key: bool, pub has_zone_keys: bool, pub has_condition_keys: bool,
}

Fields

card_trait_requirements: CardTraitRequirementsIrvalid_card: Option<CompiledSelector>valid_card_text: Option<String>valid_cards_text: Option<String>valid_player: Option<CompiledSelector>affected: Option<CompiledSelector>affected_text: Option<String>affected_zone: Option<ZoneType>affected_zone_text: Option<String>affected_zones: Vec<ZoneType>valid_zone: Vec<ZoneType>may_play: boolmay_play_alt_mana_cost: Option<String>

Mana cost string from MayPlayAltManaCost$ (e.g. Airbend’s 2). When may_play is true and this is set, the granted cast option uses this cost in place of the card’s printed mana cost.

counter_type_text: Option<String>counter_type: Option<CounterType>caster: Option<CompiledSelector>activator: Option<CompiledSelector>player: Option<CompiledSelector>valid_sa: Option<String>valid_mode: Option<String>valid_trigger: Option<String>valid_cause: Option<CompiledSelector>valid_cause_text: Option<String>valid_source: Option<CompiledSelector>valid_activator: Option<CompiledSelector>for_cost: Option<bool>is_combat: Option<bool>origin_zones: Vec<ZoneType>destination_zones: Vec<ZoneType>combat_damage: Option<bool>sorcery_speed: boolonly_sorcery_speed: boolcmc_gt: Option<String>num_limit_each_turn: Option<i32>activator_raw: Option<String>cost: Option<String>gain_control_text: Option<String>add_power_text: Option<String>add_toughness_text: Option<String>add_type_text: Option<String>set_power_text: Option<String>set_toughness_text: Option<String>add_keyword_text: Option<String>remove_all_abilities: booladd_ability_text: Option<String>add_trigger_text: Option<String>add_static_ability_text: Option<String>adjust_land_plays_text: Option<String>type_filter: Option<String>mana_conversion: Option<String>except_cause_text: Option<String>restriction_text: Option<String>x_alternative_text: Option<String>announce_text: Option<String>mana_restriction_text: Option<String>stack_description_text: Option<String>cost_desc_text: Option<String>description_text: Option<String>draw_limit: Option<i32>set_max_hand_size: Option<String>

SetMaxHandSize$ Unlimited (Reliquary Tower) or a numeric override. Stored as a raw string because Forge accepts both Unlimited and a number (and deck-builder cards use SVar expressions, though no staticability_test card currently does).

raise_max_hand_size: Option<String>

RaiseMaxHandSize$ N (Spellbook etc.) — additive to the player’s max hand size.

named_text: Option<String>trigger_text: Option<String>valid_defender: Option<CompiledSelector>valid_defender_text: Option<String>max_attackers: Option<String>max_blockers: Option<String>valid_attacked: Option<CompiledSelector>valid_creature: Option<CompiledSelector>valid_entity: Option<CompiledSelector>is_present: Option<CompiledSelector>valid_attacker: Option<CompiledSelector>valid_blocker: Option<CompiledSelector>valid_blocker_text: Option<String>valid_attacker_relative: Option<CompiledSelector>has_valid_attacker_relative: boolvalid_blocker_relative: Option<CompiledSelector>has_valid_blocker_relative: boolunless_defender_text: Option<String>kw_text: Option<String>valid_keyword_text: Option<String>value_text: Option<String>mana_type_text: Option<String>result_text: Option<String>new_time_text: Option<String>present_compare_text: Option<String>check_svar_text: Option<String>svar_compare_text: Option<String>min_text: Option<String>max_text: Option<String>additional_text: Option<String>attacker_text: Option<String>target_text: Option<String>trigger: booltwice: boolonly_source_abs: booloptional: boolnum_value: Option<i32>defender_not_nearest_to_you_in_chosen_direction: booleffect_zone_all: booleffect_zones: Vec<ZoneType>valid_target: Option<CompiledSelector>valid_target_text: Option<String>valid_spell: Option<String>for_each_shard: Option<String>amount: Option<String>min_mana: Option<i32>raise_to: boolmay_play_ignore_type: boolmay_play_ignore_color: boolmay_play_snow_ignore_color: boolcolor: Option<String>ignore_generic: boolonly_first_spell: boolunless_valid_target: boolrelative: booltarget: Option<CompiledSelector>valid_card_to_target: Option<CompiledSelector>exception_sba: boolexceptions: Option<CompiledSelector>has_valid_card: boolhas_valid_player: boolmax_num: Option<i32>active_zones: Vec<ZoneType>phases_text: Option<String>condition_text: Option<String>player_turn_text: Option<String>top_card_of_library_is: Option<String>class_level_min: Option<i32>check_third_svar: Option<String>third_svar_compare: Option<String>check_fourth_svar: Option<String>fourth_svar_compare: Option<String>add_power: booladd_toughness: boolset_power: boolset_toughness: booladd_keyword: boolgain_control_param: booladd_type: boolremove_type: booladd_color: boolremove_color: boolset_color: boolcharacteristic_defining: boolhas_text_layer_key: boolhas_type_layer_key: boolhas_color_layer_key: boolhas_ability_layer_key: boolhas_rules_layer_key: boolhas_zone_keys: boolhas_condition_keys: bool