Functions
- filter_
must_ target_ cards - meets_
must_ target_ restriction - Mirrors Java’s
StaticAbilityMustTarget.meetsMustTargetRestriction(spellAbility). This is checked after target choices are made and can invalidate the cast if a required MustTarget card was targetable but not chosen. - must_
target_ cards_ required