Module zone

Module zone 

Zone module — game zones for cards.

Mirrors Java’s forge.game.zone package.

Re-exports

pub use cost_payment_stack::CostPaymentStack;
pub use player_zone::PlayerZone;
pub use player_zone_battlefield::PlayerZoneBattlefield;
pub use zone_store::ZoneStore;

Modules

cost_payment_stack
CostPaymentStack — tracks cost payments for trigger purposes.
magic_stack
MagicStack — the game stack for spells and abilities.
player_zone
PlayerZone — a zone owned by a specific player.
player_zone_battlefield
PlayerZoneBattlefield — battlefield zone with phasing filter and meld support.
zone_store
zone_type
ZoneType — game zone types.

Structs

Zone
A game zone owned by a specific player. Each player has their own Hand, Library, Graveyard, etc. Battlefield and Stack are shared but cards still track their controller.
ZoneKey
Key for looking up a zone: (zone_type, owner).