Module magic_stack

Module magic_stack 

MagicStack — the game stack for spells and abilities.

Mirrors Java’s MagicStack.java from forge.game.zone. Spells and abilities are pushed onto the stack and resolve LIFO.

Structs

MagicStack
The game stack. Spells and abilities are added to the top and resolve LIFO. Mirrors Java’s MagicStack class.
StackEntry
An entry on the game stack (spell or ability waiting to resolve). Mirrors Java’s SpellAbilityStackInstance which wraps a SpellAbility.
UndoEntry
An undo entry tracking a spell that can be undone.