pub fn add_splice_effect(
sa: &mut SpellAbility,
game: &GameState,
splice_card_id: CardId,
)Expand description
Add a single splice effect from a card onto a spell ability.
Mirrors Java’s AbilityUtils.addSpliceEffect(SpellAbility, Card).
Appends the first spell ability of the spliced card as a sub-ability at the end of the SA chain, and adds the splice cost to the total cost.