Module counters_note_effect

Module counters_note_effect 

CountersNote effect — note the number of counters on a permanent.

Ported from Java’s CountersNoteEffect.java. Store counter amounts for later use (e.g. “noted P1P1 counters”).

Structs

CountersNoteEffect

Functions

load_counters
Load previously noted counter amounts back onto a card. Mirrors Java’s CountersNoteEffect.loadCounters(Card, CounterType).
note_counters
Note the number of counters of a specific type on a card. Mirrors Java’s CountersNoteEffect.noteCounters(Card, CounterType).