Skip to main content Module mana_effect Copy item path Source ManaEffect available_special_mana_atoms Compute the mana atoms a Produced$ Special <kind> ability can produce
for availability/playability checks (read-only over GameState). build_spell_ability Build/configure the spell ability after construction.
Mirrors Java’s ManaEffect.buildSpellAbility(SpellAbility). each_color_among_valid Collect one mana per unique color among permanents matching the valid filter. handle_special_mana Handle special mana production types.
Mirrors Java’s ManaEffect.handleSpecialMana(SpellAbility, String). resolve_special_mana Resolve special mana production types (mirrors Java ManaEffect.handleSpecialMana).
Returns a list of mana letter tokens to produce (e.g. [“W”, “U”, “B”]).