PermanentEffect — move spell to battlefield.
Mirrors Java’s PermanentEffect.java.
Handles moving a spell from the stack to the battlefield as a permanent.
This is the parent logic for both PermanentCreatureEffect and
PermanentNoncreatureEffect.
Structs
Functions
- resolve_
permanent_ common - Shared implementation for Permanent, PermanentCreature and PermanentNoncreature. Both extend PermanentEffect in Java, which simply moves the host to play.