Skip to main content Module roll_dice_effect Copy item path Source DieRollResult One die’s natural roll + any modifications applied after the fact.
Mirrors Java’s RollDiceEffect.DieRollResult. RollDiceEffect get_final_results Project DieRollResults to their post-modification values.
Mirrors Java RollDiceEffect.getFinalResults(List<DieRollResult>). get_increment_cards Return the battlefield cards under player that can currently increment a
die roll (Xenosquirrel via P1P1 counter, Night Shift via life payment).
Mirrors Java RollDiceEffect.getIncrementCards. get_natural_results Project DieRollResults to their natural values.
Mirrors Java RollDiceEffect.getNaturalResults(List<DieRollResult>). get_reroll_cards Return the battlefield cards under player that can currently reroll dice.
Mirrors Java RollDiceEffect.getRerollCards. get_results_list Wrap raw natural rolls as DieRollResults (natural == modified at start).
Mirrors Java RollDiceEffect.getResultsList(List<Integer>). make_formated_description Build a formatted description for a roll dice effect.
Mirrors Java’s RollDiceEffect.makeFormatedDescription(SpellAbility). roll_dice_for_player Roll dice for a specific player.
Mirrors Java’s RollDiceEffect.rollDiceForPlayer(Player, SpellAbility, ...). roll_dice_for_player_to_visit_attractions Roll dice for a player specifically to visit attractions.
Mirrors Java’s RollDiceEffect.rollDiceForPlayerToVisitAttractions(Player). roll_to_visit_attractions visit_attractions