Module spell_api_based

Module spell_api_based 

SpellApiBased — spell abilities backed by an API type.

Mirrors Java’s SpellApiBased.java. A spell (as opposed to an activated ability) whose resolution is dispatched through the effect system based on its ApiType.

Traits

SpellApiBased
Marker trait for API-based spell abilities.

Functions

build_spell_ability
Build a spell ability for an API-based spell. Mirrors Java’s SpellApiBased constructor which creates a Spell with an associated SpellAbilityEffect.
resolve
Resolve an API-based spell ability. Mirrors Java’s SpellApiBased.resolve() which delegates to its SpellAbilityEffect.