Structs
Enums
- Binary
Choice Kind - Java-parity binary choice kinds (
PlayerController.BinaryChoiceType). - Combat
Cost Action - The action a player takes when asked to pay an attack cost (Propaganda, Ghostly Prison).
- Game
Entity - A game entity that can be a player or a card (permanent).
Used by effects like Proliferate that operate on mixed entity lists.
Mirrors Java’s
GameEntityhierarchy used inchooseEntitiesForEffect. - Main
Phase Action - The action a player takes during a main phase.
- Mana
Cost Action - The action a player takes when interactively paying a mana cost for a spell.
- Play
Card Mode - Roll
Swap Choice - Target
Choice - A target choice that can be a player, a card, or nothing.