Static utility methods related to combat.
Functions
- can_
attack - Check if a creature can attack any legal defender.
- can_
attack_ defender - can_
attack_ next_ turn - Check if a creature could attack next turn (ignores tap/summoning sickness).
- can_
attack_ player - can_
attacker_ be_ blocked_ with_ amount - Check if a creature can be blocked with a given number of blockers.
- can_
be_ blocked - Check if an attacker can be blocked by the given set of potential blockers.
- can_
block - Check if a creature can block (basic check: untapped creature).
- can_
block_ at_ least_ one - Check if a blocker can block at least one attacker from a list.
- can_
block_ more_ creatures - Check if blocker can block more creatures than it currently is.
- can_
creature_ block - check_
declared_ attacker - Declared-attacker trigger helper.
- check_
propaganda_ effects - Check propaganda-style effects that require paying a cost to attack.
- compute_
must_ block_ targets - Get attackers that
blocker_idMUST block (if able). - could_
attack_ but_ not_ attacking - Check if a creature could attack but is not currently attacking.
- filter_
legal_ blockers - Filter blockers to only those that can legally block at least one attacker.
- find_
free_ blockers - Find blockers that are not yet assigned to block anything.
- get_
all_ requirements - Get attack constraints for a combat.
- get_
available_ attackers - get_
available_ blockers - get_
lure_ type - Determine the lure type of an attacker.
- get_
min_ num_ blockers_ for_ attacker - Get the minimum number of blockers required to block an attacker.
- get_
possible_ defenders - must_
block_ an_ attacker - Check if a blocker must block an attacker this combat.
- pay_
required_ block_ costs - Pay required block costs for a blocker.
- validate_
attackers - validate_
blocks